@@ -21,8 +21,8 @@ else
 fi
 
 
-NVIDIA_BUG_REPORT_CHANGE="$Change: 9711543 $"
-NVIDIA_BUG_REPORT_VERSION=`echo $NVIDIA_BUG_REPORT_CHANGE | tr -c -d [:digit:]`
+NVIDIA_BUG_REPORT_CHANGE='$Change: 11526957 $'
+NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 #
 # echo_metadata() - echo metadata of specified file
@@ -200,20 +200,28 @@ for log_basename in /var/log/XFree86 /var/log/Xorg; do
             log_filename="${log_basename}.${i}.${log_suffix}"
             append_silent "${log_filename}"
 
-            # look for the X configuration file referenced by this X log
+            # look for the X configuration files/directories referenced by this X log
             if [ -f ${log_filename} -a -r ${log_filename} ]; then
-                j=`grep "Using config file" ${log_filename} | cut -f 2 -d \"`
-                if [ "$j" ]; then
-                    # multiple of the logs we find above might reference the
-                    # same X configuration file; keep a list of which X
-                    # configuration files we find, and only append X
-                    # configuration files we have not already appended
-                    echo "${xconfig_file_list}" | grep ":${j}:" > /dev/null
-                    if [ "$?" != "0" ]; then
-                        xconfig_file_list="${xconfig_file_list}:${j}:"
-                        append "$j"
+                config_file=`grep "Using config file" ${log_filename} | cut -f 2 -d \"`
+                config_dir=`grep "Using config directory" ${log_filename} | cut -f 2 -d \"`
+                sys_config_dir=`grep "Using system config directory" ${log_filename} | cut -f 2 -d \"`
+                for j in "$config_file" "$config_dir" "$sys_config_dir"; do
+                    if [ "$j" ]; then
+                        # multiple of the logs we find above might reference the
+                        # same X configuration file; keep a list of which X
+                        # configuration files we find, and only append X
+                        # configuration files we have not already appended
+                        echo "${xconfig_file_list}" | grep ":${j}:" > /dev/null
+                        if [ "$?" != "0" ]; then
+                            xconfig_file_list="${xconfig_file_list}:${j}:"
+                            if [ -d "$j" ]; then
+                                append_glob "$j/*.conf"
+                            else
+                                append "$j"
+                            fi
+                        fi
                     fi
-                fi
+                done
             fi
         done
     done
