@@ -611,7 +611,7 @@ NV_DEFINE_REG_ENTRY(__NV_ENABLE_MSI, 0);
 NV_DEFINE_REG_ENTRY(__NV_MAP_REGISTERS_EARLY, 0);
 NV_DEFINE_REG_ENTRY(__NV_REGISTER_FOR_ACPI_EVENTS, 1);
 
-#if defined(NV_LINUX)
+#if defined(NV_LINUX) || defined(NV_VMWARE)
 NV_DEFINE_REG_STRING_ENTRY(__NV_REGISTRY_DWORDS, NULL);
 NV_DEFINE_REG_STRING_ENTRY(__NV_RM_MSG, NULL);
 #endif
