@@ -1,6 +1,6 @@
  /***************************************************************************\
 |*                                                                           *|
-|*       Copyright 1993-2010 NVIDIA, Corporation.  All rights reserved.      *|
+|*       Copyright 1993-2011 NVIDIA, Corporation.  All rights reserved.      *|
 |*                                                                           *|
 |*     NOTICE TO USER:   The source code  is copyrighted under  U.S. and     *|
 |*     international laws.  Users and possessors of this source code are     *|
@@ -11,7 +11,7 @@
 |*     tion and  internal comments to the code,  notices to the end user     *|
 |*     as follows:                                                           *|
 |*                                                                           *|
-|*       Copyright 1993-2010 NVIDIA, Corporation.  All rights reserved.      *|
+|*       Copyright 1993-2011 NVIDIA, Corporation.  All rights reserved.      *|
 |*                                                                           *|
 |*     NVIDIA, CORPORATION MAKES NO REPRESENTATION ABOUT THE SUITABILITY     *|
 |*     OF  THIS SOURCE  CODE  FOR ANY PURPOSE.  IT IS  PROVIDED  "AS IS"     *|
@@ -26,7 +26,7 @@
 |*     OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOURCE CODE.     *|
 |*                                                                           *|
 |*     U.S. Government  End  Users.   This source code  is a "commercial     *|
-|*     item,"  as that  term is  defined at  48 C.F.R. 2.101 (OCT 1995),     *|
+|*     item,"  as that  term is  defined at  8 C.F.R. 2.101 (OCT 1995),     *|
 |*     consisting  of "commercial  computer  software"  and  "commercial     *|
 |*     computer  software  documentation,"  as such  terms  are  used in     *|
 |*     48 C.F.R. 12.212 (SEPT 1995)  and is provided to the U.S. Govern-     *|
@@ -130,6 +130,10 @@ typedef NvU8 NvBool;
 #define NV_TRUE           ((NvBool)(0 == 0))
 #define NV_FALSE          ((NvBool)(0 != 0))
 
+/* Tristate type: NV_TRUE, NV_FALSE, NV_INDETERMINATE */
+typedef NvU8 NvTristate;
+#define NV_INDETERMINATE  ((NvTristate) 2)
+
 /* Macros to extract the low and high parts of a 64-bit unsigned integer */
 /* Also designed to work if someone happens to pass in a 32-bit integer */
 #define NvU64_HI32(n)     ((NvU32)((((NvU64)(n)) >> 32) & 0xffffffff))
@@ -369,14 +373,17 @@ typedef unsigned char *PUCHAR;
 typedef NvS16                                                       NvSFXP11_5;
 typedef NvS16                                                       NvSFXP4_12;
 typedef NvS16                                                        NvSFXP8_8;
-typedef NvS32                                                       NvSFXP27_5;
+typedef NvS32                                                       NvSFXP8_24;
 typedef NvS32                                                      NvSFXP16_16;
 typedef NvS32                                                       NvSFXP24_8;
+typedef NvS32                                                       NvSFXP27_5;
+typedef NvS32                                                       NvSFXP29_3;
 
 typedef NvU16                                                       NvUFXP4_12;
 typedef NvU32                                                       NvUFXP8_24;
 typedef NvU32                                                      NvUFXP16_16;
 typedef NvU32                                                      NvUFXP20_12;
+typedef NvU32                                                       NvUFXP24_8;
 
 /*!
  * Utility macros used in converting between signed integers and fixed-point
@@ -387,8 +394,8 @@ typedef NvU32                                                      NvUFXP20_12;
 #define NV_TYPES_FXP_INTEGER(x, y)                              ((x)+(y)-1):(y)
 #define NV_TYPES_FXP_FRACTIONAL(x, y)                                 ((y)-1):0
 #define NV_TYPES_FXP_FRACTIONAL_MSB(x, y)                       ((y)-1):((y)-1)
-#define NV_TYPES_FXP_FRACTIONAL_MSB_ONE(x, y)                        0x00000001
-#define NV_TYPES_FXP_FRACTIONAL_MSB_ZERO(x, y)                       0x00000000
+#define NV_TYPES_FXP_FRACTIONAL_MSB_ONE                              0x00000001
+#define NV_TYPES_FXP_FRACTIONAL_MSB_ZERO                             0x00000000
 /*!
  * - UNSIGNED - These are only used for unsigned.
  */
@@ -410,6 +417,11 @@ typedef NvU32                                                      NvUFXP20_12;
  * Conversion macros used for converting between integer and fixed point
  * representations.  Both signed and unsigned variants.
  *
+ * Warning:
+ * Note that most of the macros below can overflow if applied on values that can
+ * not fit the destination type.  It's caller responsibility to ensure that such
+ * situations will not occur.
+ *
  * Some conversions perform some commonly preformed tasks other than just
  * bit-shifting:
  *
@@ -437,8 +449,8 @@ typedef NvU32                                                      NvUFXP20_12;
                     ((NvUFXP##x##_##y) (fxp)))))
 
 #define NV_TYPES_UFXP_X_Y_TO_U32_ROUNDED(x, y, fxp)                           \
-    ((NV_TYPES_UFXP_X_Y_TO_U32(x, y, (fxp))) +                                \
-     (DRF_VAL(_TYPES, _FXP, _FRACTIONAL_MSB((x), (y)), (fxp))))
+    NV_TYPES_UFXP_X_Y_TO_U32(x, y, ((fxp) +                                   \
+        BIT(DRF_SHIFT(NV_TYPES_FXP_FRACTIONAL_MSB((x), (y))))))
 
 /*!
  * Signed:
@@ -464,8 +476,8 @@ typedef NvU32                                                      NvUFXP20_12;
                     NV_TYPES_SFXP_S32_SIGN_EXTENSION_POSITIVE((x), (y))))))
 
 #define NV_TYPES_SFXP_X_Y_TO_S32_ROUNDED(x, y, fxp)                           \
-    ((NV_TYPES_SFXP_X_Y_TO_S32(x, y, (fxp))) +                                \
-     (DRF_VAL(_TYPES, _FXP, _FRACTIONAL_MSB((x), (y)), (fxp))))
+    NV_TYPES_SFXP_X_Y_TO_S32(x, y, ((fxp) +                                   \
+        BIT(DRF_SHIFT(NV_TYPES_FXP_FRACTIONAL_MSB((x), (y))))))
 
 
 #include "xapi-sdk.h"       /* XAPIGEN sdk macros for C */
